library(ape)
library(DECIPHER)
library(dplyr)            
library(ggplot2)
library(reshape2)
library(betapart)
library(CommEcol)
library(ggpubr)
library(tidyverse)
library(rstatix)
library(dendextend)       
library(BiodiversityR)   
setwd("C:/Users/mon_rose/Desktop/non concatenated analysis ee 2.3 - abundance filter")

source("C:/Users/mon_rose/Desktop/functions.R")                      # access some R functions I wrote that are on the desktop



## read the raw OTU table
OTU_with_tax <- read.csv("C:/Users/mon_rose/Desktop/non concatenated analysis ee 2.3 - abundance filter/raw_OTU_with_tax95.csv")


# read in the file with data on each individual sample
Sample.Data <- read.csv("C:/Users/mon_rose/Desktop/non concatenated analysis ee 2.3/Sample Data.csv", stringsAsFactors=T)
Neg_list    <- Sample.Data[Sample.Data$Cat == "Neg",]                   # list of negative control samples
Pos_list    <- Sample.Data[Sample.Data$Cat == "Pos",]                   # list of positive control samples
Sample_list <- Sample.Data[Sample.Data$Cat == "Sample",]             # list of actual samples
Sample_list2<- droplevels(Sample_list[Sample_list$Name %in% names(OTU_with_tax),])  
NonNeg_list <- Sample.Data[Sample.Data$Cat == c("Sample", "Pos"),]
rare_list   <- droplevels(Sample_list2[Sample_list2$Project == "Trial",])



#setting read counts below 0.05% abundance to zero
colSum <- colSums(OTU_with_tax[, 4:227])
for(i in 4:227){
  keep <- (OTU_with_tax[-nrow(OTU_with_tax), i]/colSum[i-3])*100 >= 0.05  # find values above 0.05
  OTU_with_tax[,i][!keep] <- 0                                                  # set values to 0
}

write.csv(OTU_with_tax, "abundance filtered OTUs with tax.csv")


# Subtract maximum negative abundance from read abundance in other occurances of that OTU
OTU_with_tax_NoNeg <- OTU_with_tax                                                                   # new dataframe for OTU table with negs subtracted
OTU_with_tax_NoNeg$neg_max <- 
  apply(OTU_with_tax_NoNeg[,names(OTU_with_tax_NoNeg) 
                           %in% Neg_list$Name], 1, max)                                              # calculate max value for any OTU in the negative
OTU_with_tax_NoNeg[,names(OTU_with_tax_NoNeg) %in% NonNeg_list$Name] <- 
  OTU_with_tax_NoNeg[,names(OTU_with_tax_NoNeg) %in% NonNeg_list$Name] - OTU_with_tax_NoNeg$neg_max  # subtract the maximum value in the negative control from the rest of the otu abundances
OTU_with_tax_NoNeg[,names(OTU_with_tax_NoNeg) 
                   %in% NonNeg_list$Name][OTU_with_tax_NoNeg[,names(OTU_with_tax_NoNeg) 
                                                             %in% NonNeg_list$Name] < 0 ] <- 0       # convert negative values back to zero

# isolate experimental samples with negative read abundances subtracted
my_OTU_with_tax_NoNeg <- OTU_with_tax_NoNeg[, !(names(OTU_with_tax_NoNeg) %in% Neg_list$Name)]        # drop neg samples
my_OTU_with_tax_NoNeg <- my_OTU_with_tax_NoNeg[, !(names(my_OTU_with_tax_NoNeg) %in% Pos_list$Name)]  # drop positive controls
my_OTU_with_tax_NoNeg <- my_OTU_with_tax_NoNeg[,!names(my_OTU_with_tax_NoNeg) %in% c("neg_max")]      # drop the neg_max column   
my_OTU_with_tax_NoNeg$final.reads <- apply(my_OTU_with_tax_NoNeg[,names(my_OTU_with_tax_NoNeg) 
                                                                 %in% Sample_list$Name], 1, sum)      # sum up the number of reads per OTU in experimental samples
my_OTU_with_tax_NoNeg <- my_OTU_with_tax_NoNeg[my_OTU_with_tax_NoNeg$final.reads > 0, ]               # keep only OTUs present in experimental sample (get's rid of those only present in pos or neg samples)
my_OTU_with_tax_NoNeg$Taxon <- 
  paste(my_OTU_with_tax_NoNeg$Class, my_OTU_with_tax_NoNeg$Order, sep=":")           # add column with class and order concatenated
my_OTU_with_tax_NoNeg$FAMILY <- 
  paste(my_OTU_with_tax_NoNeg$Order, my_OTU_with_tax_NoNeg$Family, sep=":")          # add column with order and family concatenated
my_OTU_with_tax_NoNeg <-Phylum(my_OTU_with_tax_NoNeg)                                # add Phyla
write.csv(my_OTU_with_tax_NoNeg, "my OTUs.csv") 


# isolate positive controls with negative read abundances subtracted
pos_NoNeg <- OTU_with_tax_NoNeg[, !(names(OTU_with_tax_NoNeg) %in% Neg_list$Name)]        # drop neg samples
pos_NoNeg <- pos_NoNeg[, !(names(pos_NoNeg) %in% Sample_list$Name)]                       # drop experimental samples
pos_NoNeg <- pos_NoNeg[,!names(pos_NoNeg) %in% c("neg_max")]                              # drop the neg_max column   
pos_NoNeg$final.reads <- apply(pos_NoNeg[,names(pos_NoNeg) %in% Pos_list$Name], 1, sum)   # sum up the number of reads per OTU in pos samples
pos_NoNeg <- pos_NoNeg[pos_NoNeg$final.reads > 0, ]                                       # keep only OTUs present in my sample (get's rid of those only present in pos or neg samples)
pos_NoNeg$Taxon <- 
  paste(pos_NoNeg$Class, pos_NoNeg$Order, sep=":")                                        # add column with class and order concatenated
pos_NoNeg$FAMILY <- 
  paste(pos_NoNeg$Order, pos_NoNeg$Family, sep=":")                                       # add column with order and family concatenated
pos_NoNeg <-Phylum(pos_NoNeg)                                                             # add Phyla
write.csv(pos_NoNeg, "positive OTUs.csv") 




#### isolate the classified OTUs in experimental samples only ####
my_OTUs_with_tax <- my_OTU_with_tax_NoNeg[my_OTU_with_tax_NoNeg$Category == "Classified",]


####### compare classified OTU accumulation curves of the 8 replicates for each sample ##########
specmatrix <- t(my_OTUs_with_tax[, names(my_OTUs_with_tax) %in% Sample_list$Name])           # create a site by species matrix stored as dataframe
accum      <- accumcomp(x=specmatrix, y=Sample_list2, factor="Sample", 
                        method="random", permutations = 1000, legend =F)                     # compare accumulation of all samples
accum.long <- accumcomp.long(accum, ci=NA, label.freq=1)                                     # pull out the data for each accumulation curve
accum.long <- merge(accum.long, unique(Sample_list2[,2:18]), 
                    by.x= "Grouping", by.y = "Sample")                                       # add in sample data for plotting

pdf("All classified OTU accumulation.pdf", width=5.85, height = 4.60)
ggplot(accum.long, aes(x = Sites, y = Richness, ymax = UPR, ymin = LWR)) + 
  geom_line(aes(colour=Protocol, group = interaction(Protocol, Grouping)), size=2) +
  labs(x = "Replicates", y = "OTUs", colour = "Protocol", shape = "Sample")+
  theme_bw() 
dev.off()


####### compare arthropod OTU accumulation curves of the 8 replicates for each sample ##########
arthmatrix <- t(my_OTU_with_tax_NoNeg[my_OTU_with_tax_NoNeg$Phylum == "Arthropoda",
                                     names(my_OTU_with_tax_NoNeg) %in% Sample_list$Name])    # site by species matrix for just arthropod OTUS
accumarth <- accumcomp(x=arthmatrix, y=Sample_list2, factor="Sample", 
                       method="random", permutations = 1000, legend =F, gamma="boot")        # compare accumulation of all Arthropod OTUs

accumarth.long <- accumcomp.long(accumarth, ci=NA, label.freq=1)                             # pull out the data for each accumulation curve
accumarth.long <- merge(accumarth.long, unique(Sample_list2[,2:18]), 
                        by.x= "Grouping", by.y = "Sample")                                   # add in sample data for plotting


pdf("Arthopod OTU accumulation.pdf", width=5.85, height = 4.60)
ggplot(accumarth.long, aes(x = Sites, y = Richness, ymax = UPR, ymin = LWR)) + 
  geom_line(aes(colour=Protocol, group = interaction(Protocol, Grouping)), size=2) +
  labs(x = "Replicates", y = "OTUs", colour = "Protocol", shape = "Sample")+
  theme_bw() 
dev.off()




##### convert the OTU table to a long form dataframe for downstream analyses ####
all_OTU_long <- melt(my_OTU_with_tax_NoNeg,
                     # ID variables - all the variables to keep but not split apart on
                     id.vars=c("LABEL" , "X",  "sort",  "sequ", "ID",
                               "Phylum", "Class",  "Order", "Family", "Genus" , 
                               "Species","Subspecies" , "Similarity" , "Status",
                               "Process.ID" , "Record.ID", "BOLD.BIN", "Sex" , "Life.stage" ,
                               "Country" , "Identifier", "Identification.Method", "Institution.storing",
                               "Specimen.page.url" , "reads", "OTU_status"  ,  "Category" , 
                               "final.reads" , "Taxon", "FAMILY", "Kingdom"),
                     # Name of the destination column that will identify the original
                     # column that the measurement came from
                     variable.name="sample",
                     value.name="abundance"
)



all_OTU_long <- all_OTU_long[all_OTU_long$abundance >0,]                               # keep only rows with at least one otu rep in a replicate
all_OTU_long <- merge(all_OTU_long, Sample.Data, by.x ='sample', by.y='Name', all.x=T) # merge with the sample data information


OTU_long <- all_OTU_long[all_OTU_long$Category ==  "Classified",]                     # keep only rows with classified OTUs

OTU_long %>% summarise(count = n_distinct(ID))                                        # check for correct # of OTUs
OTU_long_other_inverts <- OTU_long[OTU_long$Kingdom == "Other invertebrates",]        # subset the other invertebrates
OTU_long_protists <- OTU_long[OTU_long$Kingdom == "Protists",]                        # subset the protists
OTU_long_arth <- OTU_long[OTU_long$Phylum == "Arthropoda",]                           # subset the arthropods
OTU_long_mite <- OTU_long[OTU_long$Order == "Mesostigmata" | OTU_long$Order == "Sarcoptiformes" | 
                            OTU_long$Order ==  "Trombidiformes",]                     # subset the mites
OTU_long_inverts <- OTU_long[OTU_long$Kingdom == "Other invertebrates" |
                               OTU_long$Kingdom == "Arthropods", ]                    # subset all inverts



#### OTUs new to BOLD ####
# by kingdom
as.data.frame(OTU_long %>% group_by(Category, Kingdom, OTU_status) %>% summarise(count = n_distinct(ID)))   ## classified vs unclassified by kingdom
OTU.status.all<- as.data.frame(OTU_long %>% group_by(Category, Kingdom, OTU_status) %>% summarise(count = n_distinct(ID)))   ## turn it into a dataframe
pdf("OTUs by kingdom_all Classified_v1.pdf", width=6, height = 4.5)
ggplot(OTU.status.all, aes(fill=reorder(OTU_status, desc(OTU_status)), y=count, x=reorder(Kingdom, desc(Kingdom)))) + 
  geom_bar(position="stack", stat="identity")+
  coord_flip()+
  theme(legend.title=element_blank())+
  labs(y="OTUs", x="")+
  theme(legend.position = "bottom",
        legend.title = element_blank(),
        plot.title = element_text(hjust = 0.5),
        panel.background = element_rect(fill =  NA))+
  xlim("Chordates", "Bacteria", "Fungi", "Protists", "Other invertebrates", "Arthropods")
dev.off()


# just inverts
OTU.status.inverts<- as.data.frame(OTU_long_other_inverts %>% group_by(Class, OTU_status) %>% summarise(count = n_distinct(ID)))
pdf("Invert OTUs Classified_v1 by class.pdf", width=6, height = 4.5)
ggplot(OTU.status.inverts, aes(fill=reorder(OTU_status, desc(OTU_status)), y=count, x=reorder(Class, count))) + 
  geom_bar(position="stack", stat="identity")+
  coord_flip()+
  theme(legend.title=element_blank())+
  labs(y="OTUs", x="")+
  theme(legend.position = "bottom",
        legend.title = element_blank(),
        plot.title = element_text(hjust = 0.5),
        panel.background = element_rect(fill =  NA))
dev.off()


# just arthropods
OTU.status.arthropods.2<- as.data.frame(OTU_long_arth %>% group_by(Taxon, OTU_status) %>% summarise(count = n_distinct(ID)))
pdf("aRthropod OTUs Classified_v2.pdf", width=6.7, height = 3.7)
ggplot(OTU.status.arthropods.2, aes(fill=reorder(OTU_status, desc(OTU_status)), y=count, x=reorder(Taxon, desc(Taxon)))) + 
  geom_bar(position="stack", stat="identity")+
  coord_flip()+
  theme(legend.title=element_blank())+
  labs(y="OTUs", x="")+
  theme(legend.position = "bottom",
        legend.title = element_blank(),
        plot.title = element_text(hjust = 0.5),
        panel.background = element_rect(fill =  NA))
dev.off()

# just arachnids
OTU.status.arachnids<- OTU.status.arthropods.2[2:12,]
pdf("Arachnid OTUs Classified_v2.pdf", width=6, height = 4.5)
ggplot(OTU.status.arachnids, aes(fill=reorder(OTU_status, desc(OTU_status)), y=count, x=reorder(Taxon, count))) + 
  geom_bar(position="stack", stat="identity")+
  coord_flip()+
  theme(legend.title=element_blank())+
  labs(y="OTUs", x="")+
  theme(legend.position = "bottom",
        legend.title = element_blank(),
        plot.title = element_text(hjust = 0.5),
        panel.background = element_rect(fill =  NA))
dev.off()

# just insects
OTU.status.insects<- OTU.status.arthropods.2[28:44,]
pdf("Insect OTUs Classified_v2.pdf", width=6, height = 4.5)
ggplot(OTU.status.insects, aes(fill=reorder(OTU_status, desc(OTU_status)), y=count, x=reorder(Taxon, count))) + 
  geom_bar(position="stack", stat="identity")+
  coord_flip()+
  theme(legend.title=element_blank())+
  labs(y="OTUs", x="")+
  theme(legend.position = "bottom",
        legend.title = element_blank(),
        plot.title = element_text(hjust = 0.5),
        panel.background = element_rect(fill =  NA))
dev.off()

# non insect and non mite arthropods
OTU.status.other<- OTU.status.arthropods.2[c(13:27, 45:47),]
pdf("Other arthropod OTUs Classified_v2.pdf", width=6, height = 4.5)
ggplot(OTU.status.other, aes(fill=reorder(OTU_status, desc(OTU_status)), y=count, x=reorder(Taxon, count))) + 
  geom_bar(position="stack", stat="identity")+
  coord_flip()+
  theme(legend.title=element_blank())+
  labs(y="OTUs", x="")+
  theme(legend.position = "bottom",
        legend.title = element_blank(),
        plot.title = element_text(hjust = 0.5),
        panel.background = element_rect(fill =  NA))
dev.off()



################# paired specimen and soil sample comparison ########################
#summary of tax and OTUs by protocol
rare.all<- droplevels(OTU_long[OTU_long$Project == "Trial",])
rare.arth <- droplevels(OTU_long[OTU_long$Project == "Trial" & OTU_long$Phylum=="Arthropoda",])
rare.mite<- droplevels(OTU_long_mite[OTU_long_mite$Project == "Trial",])
rare.other <- droplevels(OTU_long_other_inverts[OTU_long_other_inverts$Project == "Trial", ])
rare.protists <- droplevels(OTU_long_protists[OTU_long_protists$Project == "Trial", ])


# test for differences in alpha diversity for number of Orders, families, and OTUs recovered
# if shapiro.test(d) # => p-value >0.05 not significantly different from normal
# do t.test(count ~ Protocol, data = families.by.type.all, paired = TRUE, alternative = c("less")) 
# do wilcox.test(count ~ Protocol, data = OTUs.by.type.mite, paired = TRUE, alternative = c("less")) # p=0.9716, v=6 (3 samples -1)

# Orders
# all taxa
Orders.by.type.all <- as.data.frame(rare.all %>% group_by(Site, Protocol) %>% summarise(count = n_distinct(Order)))
as.data.frame(Orders.by.type.all %>% group_by(Protocol) %>% summarise(n = n(), mean = mean(count), sd = sd(count))) # mean and sd for each group
ggboxplot(Orders.by.type.all, x = "Protocol", y = "count", 
          color = "Protocol", palette = c("#00AFBB", "#E7B800"),
          ylab = "Orders", xlab = "Protocol") 
d<- with(Orders.by.type.all, count[Protocol == "Berlese Funnel"] - count[Protocol == "Bulk Soil"])
shapiro.test(d) 
wilcox.test(count ~ Protocol, data = Orders.by.type.all, paired = TRUE, alternative = c("less")) 
t.test(count ~ Protocol, data = Orders.by.type.all, paired = TRUE, alternative = c("less")) 

# arthropods
Orders.by.type.arth <- as.data.frame(rare.arth %>% group_by(Site, Protocol) %>% summarise(count = n_distinct(Order)))
as.data.frame(Orders.by.type.arth %>% group_by(Protocol) %>% summarise(n = n(), mean = mean(count), sd = sd(count))) # mean and sd for each group
ggboxplot(Orders.by.type.arth, x = "Protocol", y = "count", 
          color = "Protocol", palette = c("#00AFBB", "#E7B800"),
          ylab = "Orders", xlab = "Protocol") 
d <- with(Orders.by.type.arth, count[Protocol == "Berlese Funnel"] - count[Protocol == "Bulk Soil"])
shapiro.test(d) 
wilcox.test(count ~ Protocol, data = Orders.by.type.arth, paired = TRUE, alternative = c("less")) 
t.test(count ~ Protocol, data = Orders.by.type.arth, paired = TRUE, alternative = c("less"))  

# mites
Orders.by.type.mite <- as.data.frame(rare.mite %>% group_by(Site, Protocol) %>% summarise(count = n_distinct(Order)))
as.data.frame(Orders.by.type.mite %>% group_by(Protocol) %>% summarise(n = n(), mean = mean(count), sd = sd(count))) # mean and sd for each group
ggboxplot(Orders.by.type.mite, x = "Protocol", y = "count", 
          color = "Protocol", palette = c("#00AFBB", "#E7B800"),
          ylab = "Orders", xlab = "Protocol") 
d <- with(Orders.by.type.mite, count[Protocol == "Berlese Funnel"] - count[Protocol == "Bulk Soil"])
shapiro.test(d) 
wilcox.test(count ~ Protocol, data = Orders.by.type.mite, paired = TRUE, alternative = c("less")) 
t.test(count ~ Protocol, data = Orders.by.type.mite, paired = TRUE, alternative = c("less")) 

# other inverts (non-arthropod)
Orders.by.type.other <- as.data.frame(rare.other %>% group_by(Site, Protocol) %>% summarise(count = n_distinct(Order)))
as.data.frame(Orders.by.type.other %>% group_by(Protocol) %>% summarise(n = n(), mean = mean(count), sd = sd(count))) # mean and sd for each group
ggboxplot(Orders.by.type.other, x = "Protocol", y = "count", 
          color = "Protocol", palette = c("#00AFBB", "#E7B800"),
          ylab = "OTUs", xlab = "Protocol") 
d <- with(Orders.by.type.other, count[Protocol == "Berlese Funnel"] - count[Protocol == "Bulk Soil"])
shapiro.test(d) 
t.test(count ~ Protocol, data = Orders.by.type.other, paired = TRUE, alternative = c("less")) 
wilcox.test(count ~ Protocol, data = Orders.by.type.other, paired = TRUE, alternative = c("less")) 

# protists
Orders.by.type.pro <- as.data.frame(rare.protists %>% group_by(Site, Protocol) %>% summarise(count = n_distinct(Order)))
as.data.frame(Order.by.type.pro %>% group_by(Protocol) %>% summarise(n = n(), mean = mean(count), sd = sd(count))) 
ggboxplot(Order.by.type.pro, x = "Protocol", y = "count", 
          color = "Protocol", palette = c("#00AFBB", "#E7B800"),
          ylab = "OTUs", xlab = "Protocol") 
d <- with(Order.by.type.pro, count[Protocol == "Berlese Funnel"] - count[Protocol == "Bulk Soil"])
shapiro.test(d) 
t.test(count ~ Protocol, data = Order.by.type.pro, paired = TRUE, alternative = c("less")) 
wilcox.test(count ~ Protocol, data = Order.by.type.pro, paired = TRUE, alternative = c("less"))



#Families
# all tax
families.by.type.all <- as.data.frame(rare.all %>% group_by(Site, Protocol) %>% summarise(count = n_distinct(Family)))
as.data.frame(families.by.type.all %>% group_by(Protocol) %>% summarise(n = n(), mean = mean(count), sd = sd(count))) # mean and sd for each group
ggboxplot(families.by.type.all, x = "Protocol", y = "count", 
          color = "Protocol", palette = c("#00AFBB", "#E7B800"),
          ylab = "families", xlab = "Protocol") 
d <- with(families.by.type.all, count[Protocol == "Berlese Funnel"] - count[Protocol == "Bulk Soil"])
shapiro.test(d) 
t.test(count ~ Protocol, data = families.by.type.all, paired = TRUE, alternative = c("less"))  

# arthropods
families.by.type.arth <- as.data.frame(rare.arth %>% group_by(Site, Protocol) %>% summarise(count = n_distinct(Family)))
as.data.frame(families.by.type.arth %>% group_by(Protocol) %>% summarise(n = n(), mean = mean(count), sd = sd(count))) # mean and sd for each group
ggboxplot(families.by.type.arth, x = "Protocol", y = "count", 
          color = "Protocol", palette = c("#00AFBB", "#E7B800"),
          ylab = "families", xlab = "Protocol") 
# compute the difference - differences of pairs need to be normarthy distributed to do a paired t-test
d <- with(families.by.type.arth, count[Protocol == "Berlese Funnel"] - count[Protocol == "Bulk Soil"])
# Shapiro-Wilk normality test for the differences
shapiro.test(d) 
t.test(count ~ Protocol, data = families.by.type.arth, paired = TRUE, alternative = c("less"))  

# mites
families.by.type.mite <- as.data.frame(rare.mite %>% group_by(Site, Protocol) %>% summarise(count = n_distinct(Family)))
as.data.frame(families.by.type.mite %>% group_by(Protocol) %>% summarise(n = n(), mean = mean(count), sd = sd(count))) # mean and sd for each group
ggboxplot(families.by.type.mite, x = "Protocol", y = "count", 
          color = "Protocol", palette = c("#00AFBB", "#E7B800"),
          ylab = "families", xlab = "Protocol") 
d <- with(families.by.type.mite, count[Protocol == "Berlese Funnel"] - count[Protocol == "Bulk Soil"])
shapiro.test(d) 
t.test(count ~ Protocol, data = families.by.type.mite, paired = TRUE, alternative = c("less")) 

# other inverts
families.by.type.other <- as.data.frame(rare.other %>% group_by(Site, Protocol) %>% summarise(count = n_distinct(Family)))
as.data.frame(families.by.type.other %>% group_by(Protocol) %>% summarise(n = n(), mean = mean(count), sd = sd(count))) # mean and sd for each group
ggboxplot(families.by.type.other, x = "Protocol", y = "count", 
          color = "Protocol", palette = c("#00AFBB", "#E7B800"),
          ylab = "OTUs", xlab = "Protocol") 
d <- with(families.by.type.other, count[Protocol == "Berlese Funnel"] - count[Protocol == "Bulk Soil"])
shapiro.test(d) 
t.test(count ~ Protocol, data = families.by.type.other, paired = TRUE, alternative = c("less")) 
wilcox.test(count ~ Protocol, data = families.by.type.other, paired = TRUE, alternative = c("less")) 

# protists
families.by.type.pro <- as.data.frame(rare.protists %>% group_by(Site, Protocol) %>% summarise(count = n_distinct(Family)))
as.data.frame(families.by.type.pro %>% group_by(Protocol) %>% summarise(n = n(), mean = mean(count), sd = sd(count))) 
ggboxplot(families.by.type.pro, x = "Protocol", y = "count", 
          color = "Protocol", palette = c("#00AFBB", "#E7B800"),
          ylab = "OTUs", xlab = "Protocol") 
d <- with(families.by.type.pro, count[Protocol == "Berlese Funnel"] - count[Protocol == "Bulk Soil"])
shapiro.test(d) 
t.test(count ~ Protocol, data = families.by.type.pro, paired = TRUE, alternative = c("less")) 
wilcox.test(count ~ Protocol, data = families.by.type.pro, paired = TRUE, alternative = c("less")) 



# OTUs
# all tax
OTUs.by.type.all <- as.data.frame(rare.all %>% group_by(Site, Protocol) %>% summarise(count = n_distinct(ID)))
as.data.frame(OTUs.by.type.all %>% group_by(Protocol) %>% summarise(n = n(), mean = mean(count), sd = sd(count))) # mean and sd for each group
ggboxplot(OTUs.by.type.all, x = "Protocol", y = "count", 
          color = "Protocol", palette = c("#00AFBB", "#E7B800"),
          ylab = "OTUs", xlab = "Protocol") 
d <- with(OTUs.by.type.all, count[Protocol == "Berlese Funnel"] - count[Protocol == "Bulk Soil"])
shapiro.test(d) 
t.test(count ~ Protocol, data = OTUs.by.type.all, paired = TRUE, alternative = c("less")) ,

# arthropods
rare.arth<- droplevels(OTU_long_arth[OTU_long_arth$Project == "Trial",])
OTUs.by.type.arth <- as.data.frame(rare.arth %>% group_by(Site, Protocol) %>% summarise(count = n_distinct(ID)))
as.data.frame(OTUs.by.type.arth %>% group_by(Protocol) %>% summarise(n = n(), mean = mean(count), sd = sd(count))) # mean and sd for each group
ggboxplot(OTUs.by.type.arth, x = "Protocol", y = "count", 
          color = "Protocol", palette = c("#00AFBB", "#E7B800"),
          ylab = "OTUs", xlab = "Protocol") 
d <- with(OTUs.by.type.arth, count[Protocol == "Berlese Funnel"] - count[Protocol == "Bulk Soil"])
shapiro.test(d) 
t.test(count ~ Protocol, data = OTUs.by.type.arth, paired = TRUE, alternative = c("less")) 
wilcox.test(count ~ Protocol, data = OTUs.by.type.arth, paired = TRUE, alternative = c("less")) 

# mites
OTUs.by.type.mite <- as.data.frame(rare.mite %>% group_by(Site, Protocol) %>% summarise(count = n_distinct(ID)))
as.data.frame(OTUs.by.type.mite %>% group_by(Protocol) %>% summarise(n = n(), mean = mean(count), sd = sd(count))) # mean and sd for each group
ggboxplot(OTUs.by.type.mite, x = "Protocol", y = "count", 
          color = "Protocol", palette = c("#00AFBB", "#E7B800"),
          ylab = "OTUs", xlab = "Protocol") 
d <- with(OTUs.by.type.mite, count[Protocol == "Berlese Funnel"] - count[Protocol == "Bulk Soil"])
shapiro.test(d) 
t.test(count ~ Protocol, data = OTUs.by.type.mite, paired = TRUE, alternative = c("less")) 
wilcox.test(count ~ Protocol, data = OTUs.by.type.mite, paired = TRUE, alternative = c("less")) 

#other inverts
OTUs.by.type.other <- as.data.frame(rare.other %>% group_by(Site, Protocol) %>% summarise(count = n_distinct(ID)))
as.data.frame(OTUs.by.type.other %>% group_by(Protocol) %>% summarise(n = n(), mean = mean(count), sd = sd(count))) # mean and sd for each group
ggboxplot(OTUs.by.type.other, x = "Protocol", y = "count", 
          color = "Protocol", palette = c("#00AFBB", "#E7B800"),
          ylab = "OTUs", xlab = "Protocol") 
d <- with(OTUs.by.type.other, count[Protocol == "Berlese Funnel"] - count[Protocol == "Bulk Soil"])
shapiro.test(d) 
t.test(count ~ Protocol, data = OTUs.by.type.other, paired = TRUE, alternative = c("less")) 

# protists
OTUs.by.type.pro <- as.data.frame(rare.protists %>% group_by(Site, Protocol) %>% summarise(count = n_distinct(ID)))
as.data.frame(OTUs.by.type.pro %>% group_by(Protocol) %>% summarise(n = n(), mean = mean(count), sd = sd(count))) 
ggboxplot(OTUs.by.type.pro, x = "Protocol", y = "count", 
          color = "Protocol", palette = c("#00AFBB", "#E7B800"),
          ylab = "OTUs", xlab = "Protocol") ## check differences with boxplot - cstill overlapping but in general lower
d <- with(OTUs.by.type.pro, count[Protocol == "Berlese Funnel"] - count[Protocol == "Bulk Soil"])
shapiro.test(d) 
t.test(count ~ Protocol, data = OTUs.by.type.pro, paired = TRUE, alternative = c("less")) 




########### rare beta diversity OTU #############
rare.all<- droplevels(OTU_long[OTU_long$Project == "Trial",])
rare.all.incidence <- data.frame(unclass(table(rare.all[c("Sample.1", "ID")])))                # make a sample/species matrix
rare.all.incidence[rare.all.incidence > 1] <- 1                                                # may be present in up to 8 replicates, so convert values larger than 1 to 1  
rare.all.incidence.levels<-as.data.frame(matrix(unlist(strsplit(as.character(unique(row.names(rare.all.incidence))), '[|]')), ncol=2, byrow=TRUE))
colnames(rare.all.incidence.levels)<-c("Site", "Protocol")                                     # above is to grab the variables from the rownames, then this line names the columns
row.names(rare.all.incidence.levels) <- row.names(rare.all.incidence)
rare.all.beta<-beta.pair(rare.all.incidence, index.family = "sorensen")
rare.all.sorensen<-as.dist(rare.all.beta$beta.sor) ### dissimilarity - Sorensen = Simpson (turnover) + nestedness = total beta diversity

rare.all.sorensen.tree<-hclust(rare.all.sorensen)
plot(rare.all.sorensen.tree) 
adonis(rare.all.sorensen ~ Protocol, data=rare.all.incidence.levels, permutations = 1000) 




rare.arth<- droplevels(OTU_long_arth[OTU_long_arth$Project == "Trial" ,])
rare.arth.incidence<-data.frame(unclass(table(rare.arth[c("Sample.1", "ID")])))
rare.arth.incidence[rare.arth.incidence > 1] <- 1                                        # may be present in up to 8 replicates, so convert values larger than 1 to 1  
rare.arth.incidence.levels<-as.data.frame(matrix(unlist(strsplit(as.character(unique(row.names(rare.arth.incidence))), '[|]')), ncol=2, byrow=TRUE))
colnames(rare.arth.incidence.levels)<-c("Site", "Protocol")                              # above is to grab the variables from the rownames, then this line names the columns
row.names(rare.arth.incidence.levels) <- row.names(rare.arth.incidence)
rare.arth.beta<-beta.pair(rare.arth.incidence, index.family = "sorensen")                                  
rare.arth.sorensen<-as.dist(rare.arth.beta$beta.sor)                                     ### dissimilarity

rare.arth.sorensen.tree<-hclust(rare.arth.sorensen) 
plot(rare.arth.sorensen.tree) 
adonis(rare.arth.sorensen ~ Protocol, data=rare.arth.incidence.levels, permutations = 1000) 



rare.mite<- droplevels(OTU_long_mite[OTU_long_mite$Project == "Trial",])
rare.mite.incidence<-data.frame(unclass(table(rare.mite[c("Sample.1", "ID")])))
rare.mite.incidence[rare.mite.incidence > 1] <- 1                                        # may be present in up to 8 replicates, so convert values larger than 1 to 1  
rare.mite.beta<-beta.pair(rare.mite.incidence, index.family = "sorensen")
rare.mite.sorensen<-as.dist(rare.mite.beta$beta.sor) ### dissimilarity


rare.mite.sorensen.tree<-hclust(rare.mite.sorensen, method ="complete")
plot(rare.mite.sorensen.tree) 
adonis(rare.mite.sorensen ~ Protocol, data=rare.arth.incidence.levels, permutaitons = 1000) 




#### bulk soil sample comparison ####
bulk.all<- droplevels(OTU_long[OTU_long$Protocol == "Bulk Soil",])
bulk.arth<- droplevels(OTU_long_arth[OTU_long_arth$Protocol == "Bulk Soil" ,])
bulk.mite<- droplevels(OTU_long_mite[OTU_long_mite$Protocol == "Bulk Soil" ,])


#### bulk sample beta diversity ####
bulk.all<- droplevels(OTU_long[OTU_long$Protocol == "Bulk Soil" ,])
bulk.all %>% group_by(Site, Sample) %>% summarise(count = n_distinct(ID))
bulk.all.incidence<-data.frame(unclass(table(bulk.all[c("Sample.1", "ID")])))
bulk.all.incidence[bulk.all.incidence > 1] <- 1 
bulk.all.incidence.levels<-as.data.frame(matrix(unlist(strsplit(as.character(unique(row.names(bulk.all.incidence))), '[|]')), ncol=2, byrow=TRUE))
colnames(bulk.all.incidence.levels)<-c("Site", "Protocol") # above is to grab the variables from the rownames, then this line names the columns
row.names(bulk.all.incidence.levels) <- row.names(bulk.all.incidence)
bulk.all.beta<-beta.pair(bulk.all.incidence, index.family = "sorensen")
bulk.all.sorensen<-as.dist(bulk.all.beta$beta.sor) ### dissimilarity

bulk.all.sorensen.tree<-hclust(bulk.all.sorensen)
plot(bulk.all.sorensen.tree) 
adonis(bulk.all.sorensen ~ Site, data=bulk.all.incidence.levels, permutations = 1000) 

bulk.all.incidence.levels$Province <- c("Ontario", "Ontario", "Nunavut", "Nunavut", "Labrador", "Labrador", "Nunavut", "Nunavut", 
                                        "Labrador", "Labrador", "Ontario", "Labrador", "Labrador","Nunavut", "Nunavut","Nunavut",
                                        "Nunavut","Nunavut", "Nunavut")
bulk.all.incidence.levels$Ecoregion <- c("Eastern", "Eastern", "Tundra", "Tundra", "Cordillera", "Cordillera", "Tundra", "Tundra", 
                                         "Taiga", "Taiga", "Eastern", "Taiga", "Taiga","Tundra", "Tundra","Tundra", 
                                         "Tundra","Tundra", "Tundra") 
adonis(bulk.all.sorensen ~ Province*Site, data=bulk.all.incidence.levels, permutations = 1000) 


bulk.arth<- droplevels(OTU_long_arth[OTU_long_arth$Protocol == "Bulk Soil" ,])
bulk.arth %>% group_by(Site, Sample) %>% summarise(count = n_distinct(ID))
bulk.arth.incidence<-data.frame(unclass(table(bulk.arth[c("Sample.1", "ID")])))
bulk.arth.incidence[bulk.arth.incidence > 1] <- 1 
write.csv(bulk.arth.incidence, "Bulk arthropod incidence for parition.csv") # for partition input file
bulk.arth.incidence.levels<-as.data.frame(matrix(unlist(strsplit(as.character(unique(row.names(bulk.arth.incidence))), '[|]')), ncol=2, byrow=TRUE))
colnames(bulk.arth.incidence.levels)<-c("Site", "Protocol") # above is to grab the variables from the rownames, then this line names the columns
row.names(bulk.arth.incidence.levels) <- row.names(bulk.arth.incidence)
bulk.arth.beta<-beta.pair(bulk.arth.incidence, index.family = "sorensen")
bulk.arth.sorensen<-as.dist(bulk.arth.beta$beta.sor) ### dissimilarity

bulk.arth.sorensen.tree<-hclust(bulk.arth.sorensen)
plot(bulk.arth.sorensen.tree) # this one makes more sense
adonis(bulk.arth.sorensen ~ Site, data=bulk.arth.incidence.levels, permutations = 1000)

bulk.arth.incidence.levels$Province <- c("Ontario", "Ontario", "Nunavut", "Nunavut", "Labrador", "Labrador", "Nunavut", "Nunavut",  "Labrador", "Labrador", "Ontario", "Labrador", "Labrador","Nunavut", "Nunavut","Nunavut", "Nunavut","Nunavut", "Nunavut")
adonis(bulk.arth.sorensen ~ Province*Site, data=bulk.arth.incidence.levels, permutations = 1000) 



bulk.mite<- droplevels(OTU_long_mite[OTU_long_mite$Protocol == "Bulk Soil" & OTU_long_mite$Region != "Baffin Island",])
bulk.mite.incidence<-data.frame(unclass(table(bulk.mite[c("Sample.1", "ID")])))
bulk.mite.incidence[bulk.mite.incidence > 1] <- 1 
bulk.mite.incidence.levels<-as.data.frame(matrix(unlist(strsplit(as.character(unique(row.names(bulk.mite.incidence))), '[|]')), ncol=2, byrow=TRUE))
colnames(bulk.mite.incidence.levels)<-c("Site", "Protocol") # above is to grab the variables from the rownames, then this line names the columns
row.names(bulk.mite.incidence.levels) <- row.names(bulk.mite.incidence)
bulk.mite.beta<-beta.pair(bulk.mite.incidence, index.family = "sorensen")
bulk.mite.sorensen<-as.dist(bulk.mite.beta$beta.sor) ### dissimilarity

bulk.mite.sorensen.tree<-hclust(bulk.mite.sorensen)
plot(bulk.mite.sorensen.tree)
adonis(bulk.mite.sorensen ~ Site, data=bulk.mite.incidence.levels, permutations = 1000) 

bulk.mite.incidence.levels$Province <- c("Ontario", "Ontario", "Nunavut", "Nunavut", "Labrador", "Labrador", "Nunavut", "Labrador", "Labrador", "Ontario", "Labrador", "Labrador","Nunavut", "Nunavut","Nunavut", "Nunavut","Nunavut", "Nunavut")
adonis(bulk.mite.simpson ~ Province*Site, data=bulk.mite.incidence.levels, permutations = 1000) 



##### bulk soil distance decay ####

# Arthropods 
bulk.arth.location.data <- unique(bulk.arth[c("Sample.1", "Latitude", "Longitude")])
bulk.arth.location.data  <- bulk.arth.location.data [order(bulk.arth.location.data$Sample.1),]
colnames(bulk.arth.location.data)<-c("index", "lat", "lon")
bulk.arth.location.data$lat <- as.numeric(bulk.arth.location.data$lat)
bulk.arth.location.data$lon <- as.numeric(bulk.arth.location.data$lon)
distance.bulk.arth.mat <- GeoDistanceInMetresMatrix(bulk.arth.location.data)/1000  
distance.bulk.arth<-melt(distance.bulk.arth.mat)
distance.bulk.arth<-filter(distance.bulk.arth, Var1 != Var2)

bulk.arth.beta.sorensen <- filter(melt(as.matrix(bulk.arth.sorensen)), Var1 != Var2)
bulk.arth.beta.sorensen$distance <- distance.bulk.arth[,3]


ggplot(bulk.arth.beta.sorensen, aes(y=1-value, x=0.0001+distance))+
  geom_point()+
  geom_smooth(se = FALSE, method = "lm", formula = y ~ log(x))+
  scale_fill_grey()+
  theme(panel.border =  element_rect(colour = "black", fill=NA),
        panel.background = element_rect(colour="white"),
        axis.line = element_line(size = 0.5, linetype = "solid",colour = "black"),
        axis.text = element_text(colour ="black"))


bulk.arth.sor<- as.dist(bulk.arth.beta$beta.sor)
mantel(bulk.arth.sor, distance.bulk.arth.mat) 

# mites 
bulk.mite.location.data <- unique(bulk.mite[c("Sample.1", "Latitude", "Longitude")])
bulk.mite.location.data  <- bulk.mite.location.data [order(bulk.mite.location.data$Sample.1),]
colnames(bulk.mite.location.data)<-c("index", "lat", "lon")
bulk.mite.location.data$lat <- as.numeric(bulk.mite.location.data$lat)
bulk.mite.location.data$lon <- as.numeric(bulk.mite.location.data$lon)
distance.bulk.mite.mat <- GeoDistanceInMetresMatrix(bulk.mite.location.data)/1000 
distance.bulk.mite<-melt(distance.bulk.mite.mat)
distance.bulk.mite<-filter(distance.bulk.mite, Var1 != Var2)


bulk.mite.beta.sorensen <- filter(melt(as.matrix(bulk.mite.sorensen)), Var1 != Var2)
bulk.mite.beta.sorensen$distance <- distance.bulk.mite[,3]


ggplot(bulk.mite.beta.sorensen, aes(y=1-value, x=0.0001+distance))+
  geom_point()+
  geom_smooth(se = FALSE, method = "lm", formula = y ~ log(0.0001+x))+
  scale_fill_grey()+
  theme(panel.border =  element_rect(colour = "black", fill=NA),
        panel.background = element_rect(colour="white"),
        axis.line = element_line(size = 0.5, linetype = "solid",colour = "black"),
        axis.text = element_text(colour ="black"))

bulk.mite.sor<- as.dist(bulk.mite.beta$beta.sor)
mantel(bulk.mite.sor, distance.bulk.mite.mat) 


